Takes the lower half of a site-by-site distance (dissimilarity) matrix and creates the site-pair table. This function is called from the formatsitepair function and should not need to be called directly by the user.
createsitepair(dist, spdata, envInfo, dXCol, dYCol, siteCol, weightsType, custWeights)The lower half of a site-by-site distance (dissimilarity) matrix, provided by the formatsitepair function.
Input species data, the same as the bioData input to the formatsitepair function.
Input environmental data. Only accepts data tables as input. If the environmetal data for formatsitepair are rasters, the data would have been extracted into table format within formatsitepair.
Input x coordinate, the same as the XColumn input to the formatsitepair function.
Input y coordinate, the same as the YColumn input to the formatsitepair function.
Site column, taken from either the species or environmental tables.
The method of determining the site-pair weights.
Custom wieghts, as a vector, if given by the user.
A site-pair table with appropriate distance (dissimilarity) and weight columns used for fitting GDM.